document.addEventListener('DOMContentLoaded', () => {
  const form = document.querySelector('form');
  const reportGrid = document.querySelector('.report-grid');

  form.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const report = {
      project: document.getElementById('project-name').value,
      date: document.getElementById('report-date').value,
      achievements: document.getElementById('achievements').value,
      challenges: document.getElementById('challenges').value,
      goals: document.getElementById('goals').value,
      timestamp: new Date().toISOString()
    };

    saveReport(report);
    displayReport(report);
    form.reset();
  });

  function saveReport(report) {
    const reports = JSON.parse(localStorage.getItem('reports') || '[]');
    reports.unshift(report);
    localStorage.setItem('reports', JSON.stringify(reports));
  }

  function displayReport(report) {
    const reportCard = document.createElement('div');
    reportCard.className = 'report-card';
    reportCard.innerHTML = `
      <h3>${report.project}</h3>
      <p>${formatDate(report.date)}</p>
      <details>
        <summary>View Details</summary>
        <div class="report-details">
          <h4>Key Achievements</h4>
          <p>${report.achievements}</p>
          <h4>Challenges</h4>
          <p>${report.challenges || 'None reported'}</p>
          <h4>Next Month Goals</h4>
          <p>${report.goals}</p>
        </div>
      </details>
    `;
    reportGrid.insertBefore(reportCard, reportGrid.firstChild);
  }

  function formatDate(dateString) {
    return new Date(dateString).toLocaleDateString('en-US', {
      year: 'numeric',
      month: 'long'
    });
  }

  // Load existing reports
  const reports = JSON.parse(localStorage.getItem('reports') || '[]');
  reports.forEach(report => displayReport(report));
});